"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MediaRecorderInternal = void 0;
var _tsInterfaceChecker = require("ts-interface-checker");
var _AgoraBase = require("../AgoraBase");
var _IAgoraMediaRecorderImpl = require("../impl/IAgoraMediaRecorderImpl");
var _AgoraMediaBaseTi = _interopRequireDefault(require("../ti/AgoraMediaBase-ti"));
var _IrisApiEngine = require("./IrisApiEngine");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const checkers = (0, _tsInterfaceChecker.createCheckers)(_AgoraMediaBaseTi.default);
class MediaRecorderInternal extends _IAgoraMediaRecorderImpl.IMediaRecorderImpl {
  static _observers = new Map();
  constructor(nativeHandle) {
    super();
    this._nativeHandle = nativeHandle;
  }
  release() {
    MediaRecorderInternal._observers.delete(this._nativeHandle);
    this.removeAllListeners();
  }
  get nativeHandle() {
    return this._nativeHandle;
  }
  setMediaRecorderObserver(callback) {
    const key = this._nativeHandle;
    if (MediaRecorderInternal._observers.has(key)) {
      return _AgoraBase.ErrorCodeType.ErrOk;
    }
    MediaRecorderInternal._observers.set(key, callback);
    return super.setMediaRecorderObserver(callback);
  }
  _addListenerPreCheck(eventType) {
    var _checkers$IMediaRecor;
    if ((_checkers$IMediaRecor = checkers.IMediaRecorderObserver) !== null && _checkers$IMediaRecor !== void 0 && _checkers$IMediaRecor.strictTest({
      [eventType]: undefined
    })) {
      if (MediaRecorderInternal._observers.get(this._nativeHandle) === undefined) {
        this.setMediaRecorderObserver({});
      }
    }
    return true;
  }
  addListener(eventType, listener) {
    this._addListenerPreCheck(eventType);
    const callback = (eventProcessor, data) => {
      if (eventProcessor.type(data) !== _IrisApiEngine.EVENT_TYPE.IMediaRecorder) {
        return;
      }
      if (data.nativeHandle !== this._nativeHandle) {
        return;
      }
      eventProcessor.func.map(it => {
        it({
          [eventType]: listener
        }, eventType, data);
      });
    };
    // @ts-ignore
    listener.agoraCallback = callback;
    _IrisApiEngine.DeviceEventEmitter.addListener(eventType, callback);
  }
  removeListener(eventType, listener) {
    _IrisApiEngine.DeviceEventEmitter.removeListener(eventType,
    // @ts-ignore
    (listener === null || listener === void 0 ? void 0 : listener.agoraCallback) ?? listener);
  }
  removeAllListeners(eventType) {
    _IrisApiEngine.DeviceEventEmitter.removeAllListeners(eventType);
  }
}
exports.MediaRecorderInternal = MediaRecorderInternal;
//# sourceMappingURL=MediaRecorderInternal.js.map