"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MusicPlayerInternal = exports.MusicContentCenterInternal = exports.MusicCollectionInternal = void 0;
var _tsInterfaceChecker = require("ts-interface-checker");
var _IAgoraMusicContentCenter = require("../IAgoraMusicContentCenter");
var _IAgoraMusicContentCenterImpl = require("../impl/IAgoraMusicContentCenterImpl");
var _IAgoraMusicContentCenterTi = _interopRequireDefault(require("../ti/IAgoraMusicContentCenter-ti"));
var _IrisApiEngine = require("./IrisApiEngine");
var _MediaPlayerInternal = require("./MediaPlayerInternal");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const checkers = (0, _tsInterfaceChecker.createCheckers)(_IAgoraMusicContentCenterTi.default);
class MusicContentCenterInternal extends _IAgoraMusicContentCenterImpl.IMusicContentCenterImpl {
  static _event_handlers = [];
  _addListenerPreCheck(eventType) {
    var _checkers$IMusicConte;
    if ((_checkers$IMusicConte = checkers.IMusicContentCenterEventHandler) !== null && _checkers$IMusicConte !== void 0 && _checkers$IMusicConte.strictTest({
      [eventType]: undefined
    })) {
      if (MusicContentCenterInternal._event_handlers.length === 0) {
        this.registerEventHandler({});
      }
    }
    return true;
  }
  addListener(eventType, listener) {
    this._addListenerPreCheck(eventType);
    const callback = (eventProcessor, data) => {
      if (eventProcessor.type(data) !== _IrisApiEngine.EVENT_TYPE.IMusicContentCenter) {
        return;
      }
      eventProcessor.func.map(it => {
        it({
          [eventType]: listener
        }, eventType, data);
      });
    };
    // @ts-ignore
    listener.agoraCallback = callback;
    _IrisApiEngine.DeviceEventEmitter.addListener(eventType, callback);
  }
  removeListener(eventType, listener) {
    _IrisApiEngine.DeviceEventEmitter.removeListener(eventType,
    // @ts-ignore
    (listener === null || listener === void 0 ? void 0 : listener.agoraCallback) ?? listener);
  }
  removeAllListeners(eventType) {
    _IrisApiEngine.DeviceEventEmitter.removeAllListeners(eventType);
  }
  registerEventHandler(eventHandler) {
    if (!MusicContentCenterInternal._event_handlers.find(value => value === eventHandler)) {
      MusicContentCenterInternal._event_handlers.push(eventHandler);
    }
    return super.registerEventHandler(eventHandler);
  }
  unregisterEventHandler() {
    MusicContentCenterInternal._event_handlers = [];
    return super.unregisterEventHandler();
  }
  release() {
    MusicContentCenterInternal._event_handlers = [];
    this.removeAllListeners();
    super.release();
  }
  createMusicPlayer() {
    // @ts-ignore
    const mediaPlayerId = super.createMusicPlayer();
    return new MusicPlayerInternal(mediaPlayerId);
  }
  getApiTypeFromPreload(songCode) {
    return 'MusicContentCenter_preload2';
  }
}
exports.MusicContentCenterInternal = MusicContentCenterInternal;
class _MusicPlayerInternal extends _IAgoraMusicContentCenterImpl.IMusicPlayerImpl {
  constructor(mediaPlayerId) {
    super();
    this._mediaPlayerId = mediaPlayerId;
  }
  getMediaPlayerId() {
    return this._mediaPlayerId;
  }
  getApiTypeFromOpenWithSongCode(songCode) {
    let startPos = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return 'MusicPlayer_open';
  }
}
class MusicPlayerInternal extends _MediaPlayerInternal.MediaPlayerInternal {
  constructor(mediaPlayerId) {
    super(mediaPlayerId);
    // @ts-ignore
    this._musicPlayer = new _MusicPlayerInternal(mediaPlayerId);
  }
  openWithSongCode(songCode, startPos) {
    return this._musicPlayer.openWithSongCode(songCode, startPos);
  }
}
exports.MusicPlayerInternal = MusicPlayerInternal;
class _MusicCollection extends _IAgoraMusicContentCenter.MusicCollection {
  constructor(collection) {
    super();
    this.count = collection.count;
    this.music = collection.music;
    this.page = collection.page;
    this.pageSize = collection.pageSize;
    this.total = collection.total;
  }
  getCount() {
    return this.count;
  }
  getMusic(index) {
    return this.music[index] ?? {};
  }
  getPage() {
    return this.page;
  }
  getPageSize() {
    return this.pageSize;
  }
  getTotal() {
    return this.total;
  }
}
class MusicCollectionInternal extends _IAgoraMusicContentCenterImpl.MusicCollectionImpl {
  constructor(musicCollection) {
    super();
    this._musicCollection = new _MusicCollection(musicCollection);
  }
  getCount() {
    return this._musicCollection.getCount();
  }
  getMusic(index) {
    return this._musicCollection.getMusic(index);
  }
  getPage() {
    return this._musicCollection.getPage();
  }
  getPageSize() {
    return this._musicCollection.getPageSize();
  }
  getTotal() {
    return this._musicCollection.getTotal();
  }
}
exports.MusicCollectionInternal = MusicCollectionInternal;
//# sourceMappingURL=MusicContentCenterInternal.js.map