import { SenderOptions } from '../AgoraBase';
import { ExternalVideoSourceType } from '../AgoraMediaBase';
// @ts-ignore
export class IMediaEngineImpl {
  registerAudioFrameObserver(observer) {
    const apiType = this.getApiTypeFromRegisterAudioFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromRegisterAudioFrameObserver(observer) {
    return 'MediaEngine_registerAudioFrameObserver';
  }
  registerVideoFrameObserver(observer) {
    const apiType = this.getApiTypeFromRegisterVideoFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromRegisterVideoFrameObserver(observer) {
    return 'MediaEngine_registerVideoFrameObserver';
  }
  registerVideoEncodedFrameObserver(observer) {
    const apiType = this.getApiTypeFromRegisterVideoEncodedFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromRegisterVideoEncodedFrameObserver(observer) {
    return 'MediaEngine_registerVideoEncodedFrameObserver';
  }
  pushAudioFrame(frame) {
    let trackId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    const apiType = this.getApiTypeFromPushAudioFrame(frame, trackId);
    const jsonParams = {
      frame: frame,
      trackId: trackId,
      toJSON: () => {
        return {
          frame: frame,
          trackId: trackId
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromPushAudioFrame(frame) {
    let trackId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return 'MediaEngine_pushAudioFrame';
  }
  pullAudioFrame(frame) {
    const apiType = this.getApiTypeFromPullAudioFrame(frame);
    const jsonParams = {
      frame: frame,
      toJSON: () => {
        return {
          frame: frame
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromPullAudioFrame(frame) {
    return 'MediaEngine_pullAudioFrame';
  }
  setExternalVideoSource(enabled, useTexture) {
    let sourceType = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ExternalVideoSourceType.VideoFrame;
    let encodedVideoOption = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : new SenderOptions();
    const apiType = this.getApiTypeFromSetExternalVideoSource(enabled, useTexture, sourceType, encodedVideoOption);
    const jsonParams = {
      enabled: enabled,
      useTexture: useTexture,
      sourceType: sourceType,
      encodedVideoOption: encodedVideoOption,
      toJSON: () => {
        return {
          enabled: enabled,
          useTexture: useTexture,
          sourceType: sourceType,
          encodedVideoOption: encodedVideoOption
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromSetExternalVideoSource(enabled, useTexture) {
    let sourceType = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ExternalVideoSourceType.VideoFrame;
    let encodedVideoOption = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : new SenderOptions();
    return 'MediaEngine_setExternalVideoSource';
  }
  setExternalAudioSource(enabled, sampleRate, channels) {
    let localPlayback = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    let publish = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : true;
    const apiType = this.getApiTypeFromSetExternalAudioSource(enabled, sampleRate, channels, localPlayback, publish);
    const jsonParams = {
      enabled: enabled,
      sampleRate: sampleRate,
      channels: channels,
      localPlayback: localPlayback,
      publish: publish,
      toJSON: () => {
        return {
          enabled: enabled,
          sampleRate: sampleRate,
          channels: channels,
          localPlayback: localPlayback,
          publish: publish
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromSetExternalAudioSource(enabled, sampleRate, channels) {
    let localPlayback = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    let publish = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : true;
    return 'MediaEngine_setExternalAudioSource';
  }
  createCustomAudioTrack(trackType, config) {
    const apiType = this.getApiTypeFromCreateCustomAudioTrack(trackType, config);
    const jsonParams = {
      trackType: trackType,
      config: config,
      toJSON: () => {
        return {
          trackType: trackType,
          config: config
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromCreateCustomAudioTrack(trackType, config) {
    return 'MediaEngine_createCustomAudioTrack';
  }
  destroyCustomAudioTrack(trackId) {
    const apiType = this.getApiTypeFromDestroyCustomAudioTrack(trackId);
    const jsonParams = {
      trackId: trackId,
      toJSON: () => {
        return {
          trackId: trackId
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromDestroyCustomAudioTrack(trackId) {
    return 'MediaEngine_destroyCustomAudioTrack';
  }
  setExternalAudioSink(enabled, sampleRate, channels) {
    const apiType = this.getApiTypeFromSetExternalAudioSink(enabled, sampleRate, channels);
    const jsonParams = {
      enabled: enabled,
      sampleRate: sampleRate,
      channels: channels,
      toJSON: () => {
        return {
          enabled: enabled,
          sampleRate: sampleRate,
          channels: channels
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromSetExternalAudioSink(enabled, sampleRate, channels) {
    return 'MediaEngine_setExternalAudioSink';
  }
  enableCustomAudioLocalPlayback(trackId, enabled) {
    const apiType = this.getApiTypeFromEnableCustomAudioLocalPlayback(trackId, enabled);
    const jsonParams = {
      trackId: trackId,
      enabled: enabled,
      toJSON: () => {
        return {
          trackId: trackId,
          enabled: enabled
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromEnableCustomAudioLocalPlayback(trackId, enabled) {
    return 'MediaEngine_enableCustomAudioLocalPlayback';
  }
  pushVideoFrame(frame) {
    let videoTrackId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    const apiType = this.getApiTypeFromPushVideoFrame(frame, videoTrackId);
    const jsonParams = {
      frame: frame,
      videoTrackId: videoTrackId,
      toJSON: () => {
        return {
          frame: frame,
          videoTrackId: videoTrackId
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromPushVideoFrame(frame) {
    let videoTrackId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return 'MediaEngine_pushVideoFrame';
  }
  pushEncodedVideoImage(imageBuffer, length, videoEncodedFrameInfo) {
    let videoTrackId = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
    const apiType = this.getApiTypeFromPushEncodedVideoImage(imageBuffer, length, videoEncodedFrameInfo, videoTrackId);
    const jsonParams = {
      imageBuffer: imageBuffer,
      length: length,
      videoEncodedFrameInfo: videoEncodedFrameInfo,
      videoTrackId: videoTrackId,
      toJSON: () => {
        return {
          length: length,
          videoEncodedFrameInfo: videoEncodedFrameInfo,
          videoTrackId: videoTrackId
        };
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromPushEncodedVideoImage(imageBuffer, length, videoEncodedFrameInfo) {
    let videoTrackId = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
    return 'MediaEngine_pushEncodedVideoImage';
  }
  release() {
    const apiType = this.getApiTypeFromRelease();
    const jsonParams = {};
    callIrisApi.call(this, apiType, jsonParams);
  }
  getApiTypeFromRelease() {
    return 'MediaEngine_release';
  }
  unregisterAudioFrameObserver(observer) {
    const apiType = this.getApiTypeFromUnregisterAudioFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromUnregisterAudioFrameObserver(observer) {
    return 'MediaEngine_unregisterAudioFrameObserver';
  }
  unregisterVideoFrameObserver(observer) {
    const apiType = this.getApiTypeFromUnregisterVideoFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromUnregisterVideoFrameObserver(observer) {
    return 'MediaEngine_unregisterVideoFrameObserver';
  }
  unregisterVideoEncodedFrameObserver(observer) {
    const apiType = this.getApiTypeFromUnregisterVideoEncodedFrameObserver(observer);
    const jsonParams = {
      observer: observer,
      toJSON: () => {
        return {};
      }
    };
    const jsonResults = callIrisApi.call(this, apiType, jsonParams);
    return jsonResults.result;
  }
  getApiTypeFromUnregisterVideoEncodedFrameObserver(observer) {
    return 'MediaEngine_unregisterVideoEncodedFrameObserver';
  }
}
import { callIrisApi } from '../internal/IrisApiEngine';
//# sourceMappingURL=IAgoraMediaEngineImpl.js.map